==> mule-datasense-4.1.6-sources.jar: org/mule/datasense/impl/phases/typing/resolver/RaiseErrorTypeResolver.java <==
package org.mule.datasense.impl.phases.typing.resolver;

import org.mule.datasense.impl.model.annotations.DefinesTypeAnnotation;
import org.mule.datasense.impl.model.annotations.ThrowsErrorsTypeAnnotation;
import org.mule.datasense.impl.model.annotations.UsesTypeAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.builder.ComponentModelType;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitor;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.errorhandling.ErrorHandlingUtils;
import org.mule.runtime.api.meta.model.error.ErrorModel;
import org.mule.runtime.config.internal.model.ComponentModel;

import java.util.Collections;
import java.util.Optional;

public class RaiseErrorTypeResolver extends SingleNodeTypeResolver {

  private final static String ERROR_TYPE = "type";

  @Override
  public Optional<ComponentModelType> getComponentModelType() {
    return Optional.of(ComponentModelType.MESSAGE_PROCESSOR_NODE);
  }

  private Optional<ErrorModel> resolveErrorType(MessageProcessorNode messageProcessorNode) {
    return Optional.ofNullable(messageProcessorNode.getComponentModel())
        .map(ComponentModel::getParameters)
        .map(stringStringMap -> stringStringMap.get(ERROR_TYPE))
        .flatMap(ErrorHandlingUtils::createErrorModel);
  }

  @Override
  protected EventType resolve(MessageProcessorNode messageProcessorNode, EventType inputEventType,
                              TypingMuleAstVisitor typingMuleAstVisitor,
                              TypingMuleAstVisitorContext visitorContext) {
    messageProcessorNode.annotate(new UsesTypeAnnotation(new EventType()));

    resolveErrorType(messageProcessorNode).ifPresent(errorModel -> {
      messageProcessorNode.annotate(new ThrowsErrorsTypeAnnotation(Collections.singleton(errorModel)));
    });

    final EventType definesEventType = new EventType();
    messageProcessorNode.annotate(new DefinesTypeAnnotation(definesEventType));

    return definesEventType;
  }

  @Override
  protected boolean isPropagates(MessageProcessorNode messageProcessorNode) {
    return true;
  }
}

==> mule-datasense-4.3.0-20220919-sources.jar: org/mule/datasense/impl/phases/typing/resolver/RaiseErrorTypeResolver.java <==
package org.mule.datasense.impl.phases.typing.resolver;

import org.mule.datasense.impl.model.annotations.DefinesTypeAnnotation;
import org.mule.datasense.impl.model.annotations.ThrowsErrorsTypeAnnotation;
import org.mule.datasense.impl.model.annotations.UsesTypeAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.builder.ComponentModelType;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitor;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.errorhandling.ErrorHandlingUtils;
import org.mule.runtime.api.meta.model.error.ErrorModel;

import java.util.Collections;
import java.util.Optional;

public class RaiseErrorTypeResolver extends SingleNodeTypeResolver {

  private final static String ERROR_TYPE = "type";

  @Override
  public Optional<ComponentModelType> getComponentModelType() {
    return Optional.of(ComponentModelType.MESSAGE_PROCESSOR_NODE);
  }

  private Optional<ErrorModel> resolveErrorType(MessageProcessorNode messageProcessorNode) {
    return Optional.ofNullable(messageProcessorNode.getComponentModel())
        .map(componentModel -> (String) componentModel.getParameter(ERROR_TYPE).getValue().getRight())
        .flatMap(ErrorHandlingUtils::createErrorModel);
  }

  @Override
  protected EventType resolve(MessageProcessorNode messageProcessorNode, EventType inputEventType,
                              TypingMuleAstVisitor typingMuleAstVisitor,
                              TypingMuleAstVisitorContext visitorContext) {
    messageProcessorNode.annotate(new UsesTypeAnnotation(new EventType()));

    resolveErrorType(messageProcessorNode).ifPresent(errorModel -> {
      messageProcessorNode.annotate(new ThrowsErrorsTypeAnnotation(Collections.singleton(errorModel)));
    });

    final EventType definesEventType = new EventType();
    messageProcessorNode.annotate(new DefinesTypeAnnotation(definesEventType));

    return definesEventType;
  }

  @Override
  protected boolean isPropagates(MessageProcessorNode messageProcessorNode) {
    return true;
  }
}
